@@ -12,7 +12,7 @@ use Sub::Quote ();
 
 # RECOMMEND PREREQ: Ref::Util::XS
 
-our $VERSION = 'v0.1.7';
+our $VERSION = 'v0.1.8';
 
 # The names of all methods installed by this module.
 my %MINE;
@@ -105,7 +105,7 @@ DBIx::Class::Helper::Row::Enumeration - Add methods for emum values
 
 =head1 VERSION
 
-version v0.1.7
+version v0.1.8
 
 =head1 SYNOPSIS
 
@@ -235,6 +235,9 @@ L<DBIx::Class>
 
 L<MooseX::Enumeration>
 
+The module L<DBIx::Class::Helper::ResultSet::EnumMethods> adds
+similar methods to resultsets.
+
 =head1 SOURCE
 
 The development version is on github at L<https://github.com/robrwo/DBIx-Class-Helper-Row-Enumeration>
